# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`incron`](#incron): Main entry point for incron class which must be included in order to start managing all incron-related resources.

_Private Classes_

* `incron::config`: This class handles incron configuration files.
* `incron::install`: This class handles incron package.
* `incron::purge`: Purge `/etc/incron.d` and `/var/spool/incron` directories.
* `incron::remove`: This class handles removal of all incron-related resources.
* `incron::service`: This class handles incron service.

**Defined types**

* [`incron::job`](#incronjob): Primary incron resource used to create incron jobs.
* [`incron::whitelist`](#incronwhitelist): Use this to whitelist any system incron jobs you don't want to touch. This will make sure that `/etc/incron.d/${title}` won't get deleted nor

**Data types**

* [`Incron::Event`](#incronevent): inotify event type

## Classes

### incron

Main entry point for incron class which must be included
in order to start managing all incron-related resources.

#### Examples

##### Installing incron

```puppet
include incron
```

##### Uninstalling incron and all related resources

```puppet
class { 'incron':
  ensure => absent,
}
```

#### Parameters

The following parameters are available in the `incron` class.

##### `ensure`

Data type: `Enum[present, absent]`

Whether to enable or disable incron on the system.

Default value: present

##### `package_version`

Data type: `String[1]`

Provide custom `incron` package version here.

Default value: installed

##### `allowed_users`

Data type: `Array[String[1]]`

List of users allowed to use `incrontab(1)`. `root` will be added automatically.

Default value: [ ]

##### `denied_users`

Data type: `Array[String[1]]`

List of users specifically denied to use `incrontab(1)`.
Note: When this is not empty, all users except ones specified here will be able to use `incrontab`.

Default value: [ ]

##### `service_name`

Data type: `String[1]`

Incron service's name.

Default value: 'incrond'

##### `service_manage`

Data type: `Boolean`

Whether to manage incron service at all.

Default value: `true`

##### `service_ensure`

Data type: `Enum[running, stopped]`

Incron service's 'ensure' parameter.

Default value: running

##### `service_enable`

Data type: `Boolean`

Incron service's 'enable' parameter.

Default value: `true`

##### `purge_noop`

Data type: `Boolean`

Run purging in `noop` mode.

Default value: `false`

## Defined types

### incron::job

Primary incron resource used to create incron jobs.

#### Examples

##### Using incron::job resource

```puppet
incron::job { 'process_file':
  path    => '/upload',
  event   => 'IN_CLOSE_WRITE',
  command => '/usr/bin/process_file $#',
}
```

#### Parameters

The following parameters are available in the `incron::job` defined type.

##### `command`

Data type: `String[1]`

Command to execute on triggered event.

##### `event`

Data type: `Variant[Incron::Event,
    Array[Incron::Event, 2]]`

inotify event (or an array of events).

##### `path`

Data type: `Stdlib::Unixpath`

Path to watched directory.

##### `user`

Data type: `String[1]`

User that owns incron job.

Default value: 'root'

### incron::whitelist

Use this to whitelist any system incron jobs you don't want to touch.
This will make sure that `/etc/incron.d/${title}` won't get deleted
nor modified.

#### Examples

##### Using incron::whitelist resource

```puppet
incron::whitelist { 'uploader': }
```

## Data types

### Incron::Event

inotify event type

Alias of `Enum['IN_ALL_EVENTS', 'IN_ACCESS', 'IN_ATTRIB', 'IN_CLOSE_WRITE', 'IN_CLOSE_NOWRITE', 'IN_CREATE', 'IN_DELETE', 'IN_DELETE_SELF', 'IN_MODIFY', 'IN_MOVE_SELF', 'IN_MOVED_FROM', 'IN_MOVED_TO', 'IN_OPEN', 'IN_DONT_FOLLOW', 'IN_ONESHOT', 'IN_ONLYDIR', 'IN_NO_LOOP']`

